@@ -1,5 +1,5 @@
 
-/*  A Bison parser, made from ../../amd/conf_parse.y
+/*  A Bison parser, made from /home/ezk/proj/amd/am-utils-exp/A.sparc-sun-solaris2.8/amd/../../amd/conf_parse.y
     by GNU Bison version 1.28  */
 
 #define YYBISON 1  /* Identify Bison output.  */
@@ -12,7 +12,7 @@
 #define	NONWSEQ_STRING	262
 #define	QUOTED_NONWSEQ_STRING	263
 
-#line 45 "../../amd/conf_parse.y"
+#line 44 "conf_parse.y"
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -20,27 +20,11 @@
 #include <am_defs.h>
 #include <amd.h>
 
-/* AIX requires this to be the first thing in the file. */
-#ifndef __GNUC__
-# if HAVE_ALLOCA_H
-#  include <alloca.h>
-# else /* not HAVE_ALLOCA_H */
-#  ifdef _AIX
-#pragma alloca
-#  else /* not _AIX */
-#   ifndef alloca
-  /* predefined by HP cc +Olibcalls */
-voidp alloca();
-#   endif /* not alloca */
-#  endif /* not _AIX */
-# endif /* not HAVE_ALLOCA_H */
-#endif /* not __GNUC__ */
+extern char *conf_text;
+extern int aconf_lineno;
+extern int conf_lex(void);
 
-extern char *yytext;
-extern int yylineno;
-extern int yylex(void);
-
-static int yyerror(const char *s);
+static int conf_error(const char *s);
 static int retval;
 static char *header_section = NULL; /* start with no header section */
 
@@ -49,15 +33,15 @@ static char *header_section = NULL; /* start with no header section */
 #define PARSE_DEBUG 0
 
 #if PARSE_DEBUG
-# define dprintf(f,s) fprintf(stderr, (f), yylineno, (s))
+# define dprintf(f,s) fprintf(stderr, (f), aconf_lineno, (s))
 # define amu_return(v)
-#else
+#else /* not PARSE_DEBUG */
 # define dprintf(f,s)
 # define amu_return(v) return((v))
-#endif /* PARSE_DEBUG */
+#endif /* not PARSE_DEBUG */
 
 
-#line 90 "../../amd/conf_parse.y"
+#line 73 "conf_parse.y"
 typedef union {
 char *strtype;
 } YYSTYPE;
@@ -75,9 +59,9 @@ char *strtype;
 #define	YYFLAG		-32768
 #define	YYNTBASE	10
 
-#define YYTRANSLATE(x) ((unsigned)(x) <= 263 ? yytranslate[x] : 19)
+#define YYTRANSLATE(x) ((unsigned)(x) <= 263 ? conf_translate[x] : 19)
 
-static const char yytranslate[] = {     0,
+static const char conf_translate[] = {     0,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -108,12 +92,12 @@ static const char yytranslate[] = {     0,
 };
 
 #if YYDEBUG != 0
-static const short yyprhs[] = {     0,
+static const short conf_prhs[] = {     0,
      0,     1,     5,     6,     9,    11,    14,    16,    19,    22,
     27,    29,    32,    37,    42,    47
 };
 
-static const short yyrhs[] = {    -1,
+static const short conf_rhs[] = {    -1,
     11,    13,    14,     0,     0,    12,    14,     0,     6,     0,
      6,    13,     0,    15,     0,    15,    14,     0,    16,    17,
      0,     3,     7,     4,     6,     0,    18,     0,    18,    17,
@@ -124,49 +108,49 @@ static const short yyrhs[] = {    -1,
 #endif
 
 #if YYDEBUG != 0
-static const short yyrline[] = { 0,
-   104,   104,   105,   106,   108,   109,   112,   113,   116,   119,
-   127,   128,   131,   141,   151,   161
+static const short conf_rline[] = { 0,
+    87,    87,    88,    89,    91,    92,    95,    96,    99,   102,
+   110,   111,   114,   124,   134,   144
 };
 #endif
 
 
 #if YYDEBUG != 0 || defined (YYERROR_VERBOSE)
 
-static const char * const yytname[] = {   "$","error","$undefined.","LEFT_BRACKET",
+static const char * const conf_tname[] = {   "$","error","$undefined.","LEFT_BRACKET",
 "RIGHT_BRACKET","EQUAL","NEWLINE","NONWS_STRING","NONWSEQ_STRING","QUOTED_NONWSEQ_STRING",
 "file","@1","@2","newlines","map_sections","map_section","sec_header","kv_pairs",
 "kv_pair", NULL
 };
 #endif
 
-static const short yyr1[] = {     0,
+static const short conf_r1[] = {     0,
     11,    10,    12,    10,    13,    13,    14,    14,    15,    16,
     17,    17,    18,    18,    18,    18
 };
 
-static const short yyr2[] = {     0,
+static const short conf_r2[] = {     0,
      0,     3,     0,     2,     1,     2,     1,     2,     2,     4,
      1,     2,     4,     4,     4,     1
 };
 
-static const short yydefact[] = {     1,
+static const short conf_defact[] = {     1,
      0,     0,     5,     0,     0,     4,     7,     0,     6,     2,
      0,     8,    16,     0,     9,    11,     0,     0,    12,    10,
      0,     0,     0,    13,    14,    15,     0,     0,     0
 };
 
-static const short yydefgoto[] = {    27,
+static const short conf_defgoto[] = {    27,
      1,     2,     4,     6,     7,     8,    15,    16
 };
 
-static const short yypact[] = {     4,
+static const short conf_pact[] = {     4,
      2,     6,     2,     6,     3,-32768,     6,    -5,-32768,-32768,
      7,-32768,-32768,     8,-32768,    -5,     9,    -3,-32768,-32768,
     10,    11,    12,-32768,-32768,-32768,    14,    19,-32768
 };
 
-static const short yypgoto[] = {-32768,
+static const short conf_pgoto[] = {-32768,
 -32768,-32768,    17,    -4,-32768,-32768,     5,-32768
 };
 
@@ -174,19 +158,19 @@ static const short yypgoto[] = {-32768,
 #define	YYLAST		21
 
 
-static const short yytable[] = {    10,
+static const short conf_table[] = {    10,
     13,    14,    12,    21,    22,    23,    -3,     3,     5,    11,
     17,     0,    18,    28,    20,    24,    25,    26,    29,     9,
     19
 };
 
-static const short yycheck[] = {     4,
+static const short conf_check[] = {     4,
      6,     7,     7,     7,     8,     9,     3,     6,     3,     7,
      4,    -1,     5,     0,     6,     6,     6,     6,     0,     3,
     16
 };
 /* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
-#line 3 "/usr/local/gnu/share/bison.simple"
+#line 3 "/usr/local/share/bison.simple"
 /* This file comes from bison-1.28.  */
 
 /* Skeleton output parser for bison,
@@ -269,50 +253,50 @@ static const short yycheck[] = {     4,
    It is replaced by the list of actions, each action
    as one case of the switch.  */
 
-#define yyerrok		(yyerrstatus = 0)
-#define yyclearin	(yychar = YYEMPTY)
+#define conf_errok		(conf_errstatus = 0)
+#define conf_clearin	(conf_char = YYEMPTY)
 #define YYEMPTY		-2
 #define YYEOF		0
-#define YYACCEPT	goto yyacceptlab
-#define YYABORT 	goto yyabortlab
-#define YYERROR		goto yyerrlab1
-/* Like YYERROR except do call yyerror.
+#define YYACCEPT	goto conf_acceptlab
+#define YYABORT 	goto conf_abortlab
+#define YYERROR		goto conf_errlab1
+/* Like YYERROR except do call conf_error.
    This remains here temporarily to ease the
    transition to the new meaning of YYERROR, for GCC.
    Once GCC version 2 has supplanted version 1, this can go.  */
-#define YYFAIL		goto yyerrlab
-#define YYRECOVERING()  (!!yyerrstatus)
+#define YYFAIL		goto conf_errlab
+#define YYRECOVERING()  (!!conf_errstatus)
 #define YYBACKUP(token, value) \
 do								\
-  if (yychar == YYEMPTY && yylen == 1)				\
-    { yychar = (token), yylval = (value);			\
-      yychar1 = YYTRANSLATE (yychar);				\
+  if (conf_char == YYEMPTY && conf_len == 1)				\
+    { conf_char = (token), conf_lval = (value);			\
+      conf_char1 = YYTRANSLATE (conf_char);				\
       YYPOPSTACK;						\
-      goto yybackup;						\
+      goto conf_backup;						\
     }								\
   else								\
-    { yyerror ("syntax error: cannot back up"); YYERROR; }	\
+    { conf_error ("syntax error: cannot back up"); YYERROR; }	\
 while (0)
 
 #define YYTERROR	1
 #define YYERRCODE	256
 
 #ifndef YYPURE
-#define YYLEX		yylex()
+#define YYLEX		conf_lex()
 #endif
 
 #ifdef YYPURE
 #ifdef YYLSP_NEEDED
 #ifdef YYLEX_PARAM
-#define YYLEX		yylex(&yylval, &yylloc, YYLEX_PARAM)
+#define YYLEX		conf_lex(&conf_lval, &conf_lloc, YYLEX_PARAM)
 #else
-#define YYLEX		yylex(&yylval, &yylloc)
+#define YYLEX		conf_lex(&conf_lval, &conf_lloc)
 #endif
 #else /* not YYLSP_NEEDED */
 #ifdef YYLEX_PARAM
-#define YYLEX		yylex(&yylval, YYLEX_PARAM)
+#define YYLEX		conf_lex(&conf_lval, YYLEX_PARAM)
 #else
-#define YYLEX		yylex(&yylval)
+#define YYLEX		conf_lex(&conf_lval)
 #endif
 #endif /* not YYLSP_NEEDED */
 #endif
@@ -321,20 +305,20 @@ while (0)
 
 #ifndef YYPURE
 
-int	yychar;			/*  the lookahead symbol		*/
-YYSTYPE	yylval;			/*  the semantic value of the		*/
+int	conf_char;			/*  the lookahead symbol		*/
+YYSTYPE	conf_lval;			/*  the semantic value of the		*/
 				/*  lookahead symbol			*/
 
 #ifdef YYLSP_NEEDED
-YYLTYPE yylloc;			/*  location data for the lookahead	*/
+YYLTYPE conf_lloc;			/*  location data for the lookahead	*/
 				/*  symbol				*/
 #endif
 
-int yynerrs;			/*  number of parse errors so far       */
+int conf_nerrs;			/*  number of parse errors so far       */
 #endif  /* not YYPURE */
 
 #if YYDEBUG != 0
-int yydebug;			/*  nonzero means print parse trace	*/
+int conf_debug;			/*  nonzero means print parse trace	*/
 /* Since this is uninitialized, it does not stop multiple parsers
    from coexisting.  */
 #endif
@@ -356,20 +340,20 @@ int yydebug;			/*  nonzero means print parse trace	*/
 #define YYMAXDEPTH 10000
 #endif
 
-/* Define __yy_memcpy.  Note that the size argument
+/* Define __conf__memcpy.  Note that the size argument
    should be passed with type unsigned int, because that is what the non-GCC
    definitions require.  With GCC, __builtin_memcpy takes an arg
    of type size_t, but it can handle unsigned int.  */
 
 #if __GNUC__ > 1		/* GNU C and GNU C++ define this.  */
-#define __yy_memcpy(TO,FROM,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
+#define __conf__memcpy(TO,FROM,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
 #else				/* not GNU C or C++ */
 #ifndef __cplusplus
 
 /* This is the most reliable way to avoid incompatibilities
    in available built-in functions on various systems.  */
 static void
-__yy_memcpy (to, from, count)
+__conf__memcpy (to, from, count)
      char *to;
      char *from;
      unsigned int count;
@@ -387,7 +371,7 @@ __yy_memcpy (to, from, count)
 /* This is the most reliable way to avoid incompatibilities
    in available built-in functions on various systems.  */
 static void
-__yy_memcpy (char *to, char *from, unsigned int count)
+__conf__memcpy (char *to, char *from, unsigned int count)
 {
   register char *t = to;
   register char *f = from;
@@ -400,10 +384,10 @@ __yy_memcpy (char *to, char *from, unsigned int count)
 #endif
 #endif
 
-#line 217 "/usr/local/gnu/share/bison.simple"
+#line 217 "/usr/local/share/bison.simple"
 
 /* The user can define YYPARSE_PARAM as the name of an argument to be passed
-   into yyparse.  The argument should have type void *.
+   into conf_parse.  The argument should have type void *.
    It should actually point to an object.
    Grammar actions can access the variable by casting it
    to the proper pointer type.  */
@@ -424,399 +408,399 @@ __yy_memcpy (char *to, char *from, unsigned int count)
 /* Prevent warning if -Wstrict-prototypes.  */
 #ifdef __GNUC__
 #ifdef YYPARSE_PARAM
-int yyparse (void *);
+int conf_parse (void *);
 #else
-int yyparse (void);
+int conf_parse (void);
 #endif
 #endif
 
 int
-yyparse(YYPARSE_PARAM_ARG)
+conf_parse(YYPARSE_PARAM_ARG)
      YYPARSE_PARAM_DECL
 {
-  register int yystate;
-  register int yyn;
-  register short *yyssp;
-  register YYSTYPE *yyvsp;
-  int yyerrstatus;	/*  number of tokens to shift before error messages enabled */
-  int yychar1 = 0;		/*  lookahead token as an internal (translated) token number */
+  register int conf_state;
+  register int conf_n;
+  register short *conf_ssp;
+  register YYSTYPE *conf_vsp;
+  int conf_errstatus;	/*  number of tokens to shift before error messages enabled */
+  int conf_char1 = 0;		/*  lookahead token as an internal (translated) token number */
 
-  short	yyssa[YYINITDEPTH];	/*  the state stack			*/
-  YYSTYPE yyvsa[YYINITDEPTH];	/*  the semantic value stack		*/
+  short	conf_ssa[YYINITDEPTH];	/*  the state stack			*/
+  YYSTYPE conf_vsa[YYINITDEPTH];	/*  the semantic value stack		*/
 
-  short *yyss = yyssa;		/*  refer to the stacks thru separate pointers */
-  YYSTYPE *yyvs = yyvsa;	/*  to allow yyoverflow to reallocate them elsewhere */
+  short *conf_ss = conf_ssa;		/*  refer to the stacks thru separate pointers */
+  YYSTYPE *conf_vs = conf_vsa;	/*  to allow conf_overflow to reallocate them elsewhere */
 
 #ifdef YYLSP_NEEDED
-  YYLTYPE yylsa[YYINITDEPTH];	/*  the location stack			*/
-  YYLTYPE *yyls = yylsa;
-  YYLTYPE *yylsp;
+  YYLTYPE conf_lsa[YYINITDEPTH];	/*  the location stack			*/
+  YYLTYPE *conf_ls = conf_lsa;
+  YYLTYPE *conf_lsp;
 
-#define YYPOPSTACK   (yyvsp--, yyssp--, yylsp--)
+#define YYPOPSTACK   (conf_vsp--, conf_ssp--, conf_lsp--)
 #else
-#define YYPOPSTACK   (yyvsp--, yyssp--)
+#define YYPOPSTACK   (conf_vsp--, conf_ssp--)
 #endif
 
-  int yystacksize = YYINITDEPTH;
-  int yyfree_stacks = 0;
+  int conf_stacksize = YYINITDEPTH;
+  int conf_free_stacks = 0;
 
 #ifdef YYPURE
-  int yychar;
-  YYSTYPE yylval;
-  int yynerrs;
+  int conf_char;
+  YYSTYPE conf_lval;
+  int conf_nerrs;
 #ifdef YYLSP_NEEDED
-  YYLTYPE yylloc;
+  YYLTYPE conf_lloc;
 #endif
 #endif
 
-  YYSTYPE yyval;		/*  the variable used to return		*/
+  YYSTYPE conf_val;		/*  the variable used to return		*/
 				/*  semantic values from the action	*/
 				/*  routines				*/
 
-  int yylen;
+  int conf_len;
 
 #if YYDEBUG != 0
-  if (yydebug)
+  if (conf_debug)
     fprintf(stderr, "Starting parse\n");
 #endif
 
-  yystate = 0;
-  yyerrstatus = 0;
-  yynerrs = 0;
-  yychar = YYEMPTY;		/* Cause a token to be read.  */
+  conf_state = 0;
+  conf_errstatus = 0;
+  conf_nerrs = 0;
+  conf_char = YYEMPTY;		/* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
 
-  yyssp = yyss - 1;
-  yyvsp = yyvs;
+  conf_ssp = conf_ss - 1;
+  conf_vsp = conf_vs;
 #ifdef YYLSP_NEEDED
-  yylsp = yyls;
+  conf_lsp = conf_ls;
 #endif
 
-/* Push a new state, which is found in  yystate  .  */
+/* Push a new state, which is found in  conf_state  .  */
 /* In all cases, when you get here, the value and location stacks
    have just been pushed. so pushing a state here evens the stacks.  */
-yynewstate:
+conf_newstate:
 
-  *++yyssp = yystate;
+  *++conf_ssp = conf_state;
 
-  if (yyssp >= yyss + yystacksize - 1)
+  if (conf_ssp >= conf_ss + conf_stacksize - 1)
     {
       /* Give user a chance to reallocate the stack */
       /* Use copies of these so that the &'s don't force the real ones into memory. */
-      YYSTYPE *yyvs1 = yyvs;
-      short *yyss1 = yyss;
+      YYSTYPE *conf_vs1 = conf_vs;
+      short *conf_ss1 = conf_ss;
 #ifdef YYLSP_NEEDED
-      YYLTYPE *yyls1 = yyls;
+      YYLTYPE *conf_ls1 = conf_ls;
 #endif
 
       /* Get the current used size of the three stacks, in elements.  */
-      int size = yyssp - yyss + 1;
+      int size = conf_ssp - conf_ss + 1;
 
-#ifdef yyoverflow
+#ifdef conf_overflow
       /* Each stack pointer address is followed by the size of
 	 the data in use in that stack, in bytes.  */
 #ifdef YYLSP_NEEDED
       /* This used to be a conditional around just the two extra args,
-	 but that might be undefined if yyoverflow is a macro.  */
-      yyoverflow("parser stack overflow",
-		 &yyss1, size * sizeof (*yyssp),
-		 &yyvs1, size * sizeof (*yyvsp),
-		 &yyls1, size * sizeof (*yylsp),
-		 &yystacksize);
+	 but that might be undefined if conf_overflow is a macro.  */
+      conf_overflow("parser stack overflow",
+		 &conf_ss1, size * sizeof (*conf_ssp),
+		 &conf_vs1, size * sizeof (*conf_vsp),
+		 &conf_ls1, size * sizeof (*conf_lsp),
+		 &conf_stacksize);
 #else
-      yyoverflow("parser stack overflow",
-		 &yyss1, size * sizeof (*yyssp),
-		 &yyvs1, size * sizeof (*yyvsp),
-		 &yystacksize);
+      conf_overflow("parser stack overflow",
+		 &conf_ss1, size * sizeof (*conf_ssp),
+		 &conf_vs1, size * sizeof (*conf_vsp),
+		 &conf_stacksize);
 #endif
 
-      yyss = yyss1; yyvs = yyvs1;
+      conf_ss = conf_ss1; conf_vs = conf_vs1;
 #ifdef YYLSP_NEEDED
-      yyls = yyls1;
+      conf_ls = conf_ls1;
 #endif
-#else /* no yyoverflow */
+#else /* no conf_overflow */
       /* Extend the stack our own way.  */
-      if (yystacksize >= YYMAXDEPTH)
+      if (conf_stacksize >= YYMAXDEPTH)
 	{
-	  yyerror("parser stack overflow");
-	  if (yyfree_stacks)
+	  conf_error("parser stack overflow");
+	  if (conf_free_stacks)
 	    {
-	      free (yyss);
-	      free (yyvs);
+	      free (conf_ss);
+	      free (conf_vs);
 #ifdef YYLSP_NEEDED
-	      free (yyls);
+	      free (conf_ls);
 #endif
 	    }
 	  return 2;
 	}
-      yystacksize *= 2;
-      if (yystacksize > YYMAXDEPTH)
-	yystacksize = YYMAXDEPTH;
+      conf_stacksize *= 2;
+      if (conf_stacksize > YYMAXDEPTH)
+	conf_stacksize = YYMAXDEPTH;
 #ifndef YYSTACK_USE_ALLOCA
-      yyfree_stacks = 1;
+      conf_free_stacks = 1;
 #endif
-      yyss = (short *) YYSTACK_ALLOC (yystacksize * sizeof (*yyssp));
-      __yy_memcpy ((char *)yyss, (char *)yyss1,
-		   size * (unsigned int) sizeof (*yyssp));
-      yyvs = (YYSTYPE *) YYSTACK_ALLOC (yystacksize * sizeof (*yyvsp));
-      __yy_memcpy ((char *)yyvs, (char *)yyvs1,
-		   size * (unsigned int) sizeof (*yyvsp));
+      conf_ss = (short *) YYSTACK_ALLOC (conf_stacksize * sizeof (*conf_ssp));
+      __conf__memcpy ((char *)conf_ss, (char *)conf_ss1,
+		   size * (unsigned int) sizeof (*conf_ssp));
+      conf_vs = (YYSTYPE *) YYSTACK_ALLOC (conf_stacksize * sizeof (*conf_vsp));
+      __conf__memcpy ((char *)conf_vs, (char *)conf_vs1,
+		   size * (unsigned int) sizeof (*conf_vsp));
 #ifdef YYLSP_NEEDED
-      yyls = (YYLTYPE *) YYSTACK_ALLOC (yystacksize * sizeof (*yylsp));
-      __yy_memcpy ((char *)yyls, (char *)yyls1,
-		   size * (unsigned int) sizeof (*yylsp));
+      conf_ls = (YYLTYPE *) YYSTACK_ALLOC (conf_stacksize * sizeof (*conf_lsp));
+      __conf__memcpy ((char *)conf_ls, (char *)conf_ls1,
+		   size * (unsigned int) sizeof (*conf_lsp));
 #endif
-#endif /* no yyoverflow */
+#endif /* no conf_overflow */
 
-      yyssp = yyss + size - 1;
-      yyvsp = yyvs + size - 1;
+      conf_ssp = conf_ss + size - 1;
+      conf_vsp = conf_vs + size - 1;
 #ifdef YYLSP_NEEDED
-      yylsp = yyls + size - 1;
+      conf_lsp = conf_ls + size - 1;
 #endif
 
 #if YYDEBUG != 0
-      if (yydebug)
-	fprintf(stderr, "Stack size increased to %d\n", yystacksize);
+      if (conf_debug)
+	fprintf(stderr, "Stack size increased to %d\n", conf_stacksize);
 #endif
 
-      if (yyssp >= yyss + yystacksize - 1)
+      if (conf_ssp >= conf_ss + conf_stacksize - 1)
 	YYABORT;
     }
 
 #if YYDEBUG != 0
-  if (yydebug)
-    fprintf(stderr, "Entering state %d\n", yystate);
+  if (conf_debug)
+    fprintf(stderr, "Entering state %d\n", conf_state);
 #endif
 
-  goto yybackup;
- yybackup:
+  goto conf_backup;
+ conf_backup:
 
 /* Do appropriate processing given the current state.  */
 /* Read a lookahead token if we need one and don't already have one.  */
-/* yyresume: */
+/* conf_resume: */
 
   /* First try to decide what to do without reference to lookahead token.  */
 
-  yyn = yypact[yystate];
-  if (yyn == YYFLAG)
-    goto yydefault;
+  conf_n = conf_pact[conf_state];
+  if (conf_n == YYFLAG)
+    goto conf_default;
 
   /* Not known => get a lookahead token if don't already have one.  */
 
-  /* yychar is either YYEMPTY or YYEOF
+  /* conf_char is either YYEMPTY or YYEOF
      or a valid token in external form.  */
 
-  if (yychar == YYEMPTY)
+  if (conf_char == YYEMPTY)
     {
 #if YYDEBUG != 0
-      if (yydebug)
+      if (conf_debug)
 	fprintf(stderr, "Reading a token: ");
 #endif
-      yychar = YYLEX;
+      conf_char = YYLEX;
     }
 
-  /* Convert token to internal form (in yychar1) for indexing tables with */
+  /* Convert token to internal form (in conf_char1) for indexing tables with */
 
-  if (yychar <= 0)		/* This means end of input. */
+  if (conf_char <= 0)		/* This means end of input. */
     {
-      yychar1 = 0;
-      yychar = YYEOF;		/* Don't call YYLEX any more */
+      conf_char1 = 0;
+      conf_char = YYEOF;		/* Don't call YYLEX any more */
 
 #if YYDEBUG != 0
-      if (yydebug)
+      if (conf_debug)
 	fprintf(stderr, "Now at end of input.\n");
 #endif
     }
   else
     {
-      yychar1 = YYTRANSLATE(yychar);
+      conf_char1 = YYTRANSLATE(conf_char);
 
 #if YYDEBUG != 0
-      if (yydebug)
+      if (conf_debug)
 	{
-	  fprintf (stderr, "Next token is %d (%s", yychar, yytname[yychar1]);
+	  fprintf (stderr, "Next token is %d (%s", conf_char, conf_tname[conf_char1]);
 	  /* Give the individual parser a way to print the precise meaning
 	     of a token, for further debugging info.  */
 #ifdef YYPRINT
-	  YYPRINT (stderr, yychar, yylval);
+	  YYPRINT (stderr, conf_char, conf_lval);
 #endif
 	  fprintf (stderr, ")\n");
 	}
 #endif
     }
 
-  yyn += yychar1;
-  if (yyn < 0 || yyn > YYLAST || yycheck[yyn] != yychar1)
-    goto yydefault;
+  conf_n += conf_char1;
+  if (conf_n < 0 || conf_n > YYLAST || conf_check[conf_n] != conf_char1)
+    goto conf_default;
 
-  yyn = yytable[yyn];
+  conf_n = conf_table[conf_n];
 
-  /* yyn is what to do for this token type in this state.
-     Negative => reduce, -yyn is rule number.
-     Positive => shift, yyn is new state.
+  /* conf_n is what to do for this token type in this state.
+     Negative => reduce, -conf_n is rule number.
+     Positive => shift, conf_n is new state.
        New state is final state => don't bother to shift,
        just return success.
      0, or most negative number => error.  */
 
-  if (yyn < 0)
+  if (conf_n < 0)
     {
-      if (yyn == YYFLAG)
-	goto yyerrlab;
-      yyn = -yyn;
-      goto yyreduce;
+      if (conf_n == YYFLAG)
+	goto conf_errlab;
+      conf_n = -conf_n;
+      goto conf_reduce;
     }
-  else if (yyn == 0)
-    goto yyerrlab;
+  else if (conf_n == 0)
+    goto conf_errlab;
 
-  if (yyn == YYFINAL)
+  if (conf_n == YYFINAL)
     YYACCEPT;
 
   /* Shift the lookahead token.  */
 
 #if YYDEBUG != 0
-  if (yydebug)
-    fprintf(stderr, "Shifting token %d (%s), ", yychar, yytname[yychar1]);
+  if (conf_debug)
+    fprintf(stderr, "Shifting token %d (%s), ", conf_char, conf_tname[conf_char1]);
 #endif
 
   /* Discard the token being shifted unless it is eof.  */
-  if (yychar != YYEOF)
-    yychar = YYEMPTY;
+  if (conf_char != YYEOF)
+    conf_char = YYEMPTY;
 
-  *++yyvsp = yylval;
+  *++conf_vsp = conf_lval;
 #ifdef YYLSP_NEEDED
-  *++yylsp = yylloc;
+  *++conf_lsp = conf_lloc;
 #endif
 
   /* count tokens shifted since error; after three, turn off error status.  */
-  if (yyerrstatus) yyerrstatus--;
+  if (conf_errstatus) conf_errstatus--;
 
-  yystate = yyn;
-  goto yynewstate;
+  conf_state = conf_n;
+  goto conf_newstate;
 
 /* Do the default action for the current state.  */
-yydefault:
+conf_default:
 
-  yyn = yydefact[yystate];
-  if (yyn == 0)
-    goto yyerrlab;
+  conf_n = conf_defact[conf_state];
+  if (conf_n == 0)
+    goto conf_errlab;
 
-/* Do a reduction.  yyn is the number of a rule to reduce with.  */
-yyreduce:
-  yylen = yyr2[yyn];
-  if (yylen > 0)
-    yyval = yyvsp[1-yylen]; /* implement default value of the action */
+/* Do a reduction.  conf_n is the number of a rule to reduce with.  */
+conf_reduce:
+  conf_len = conf_r2[conf_n];
+  if (conf_len > 0)
+    conf_val = conf_vsp[1-conf_len]; /* implement default value of the action */
 
 #if YYDEBUG != 0
-  if (yydebug)
+  if (conf_debug)
     {
       int i;
 
       fprintf (stderr, "Reducing via rule %d (line %d), ",
-	       yyn, yyrline[yyn]);
+	       conf_n, conf_rline[conf_n]);
 
       /* Print the symbols being reduced, and their result.  */
-      for (i = yyprhs[yyn]; yyrhs[i] > 0; i++)
-	fprintf (stderr, "%s ", yytname[yyrhs[i]]);
-      fprintf (stderr, " -> %s\n", yytname[yyr1[yyn]]);
+      for (i = conf_prhs[conf_n]; conf_rhs[i] > 0; i++)
+	fprintf (stderr, "%s ", conf_tname[conf_rhs[i]]);
+      fprintf (stderr, " -> %s\n", conf_tname[conf_r1[conf_n]]);
     }
 #endif
 
 
-  switch (yyn) {
+  switch (conf_n) {
 
 case 1:
-#line 104 "../../amd/conf_parse.y"
-{ yydebug = PARSE_DEBUG; ;
+#line 87 "conf_parse.y"
+{ conf_debug = PARSE_DEBUG; ;
     break;}
 case 3:
-#line 105 "../../amd/conf_parse.y"
-{ yydebug = PARSE_DEBUG; ;
+#line 88 "conf_parse.y"
+{ conf_debug = PARSE_DEBUG; ;
     break;}
 case 10:
-#line 120 "../../amd/conf_parse.y"
+#line 103 "conf_parse.y"
 {
-		  if (yydebug)
-		    fprintf(stderr, "sec_header1 = \"%s\"\n", yyvsp[-2].strtype);
-		  header_section = yyvsp[-2].strtype;
+		  if (conf_debug)
+		    fprintf(stderr, "sec_header1 = \"%s\"\n", conf_vsp[-2].strtype);
+		  header_section = conf_vsp[-2].strtype;
 		;
     break;}
 case 13:
-#line 132 "../../amd/conf_parse.y"
+#line 115 "conf_parse.y"
 {
-		  if (yydebug)
-		    fprintf(stderr,"parse1: key=\"%s\", val=\"%s\"\n", yyvsp[-3].strtype, yyvsp[-1].strtype);
-		  retval = set_conf_kv(header_section, yyvsp[-3].strtype, yyvsp[-1].strtype);
+		  if (conf_debug)
+		    fprintf(stderr,"parse1: key=\"%s\", val=\"%s\"\n", conf_vsp[-3].strtype, conf_vsp[-1].strtype);
+		  retval = set_conf_kv(header_section, conf_vsp[-3].strtype, conf_vsp[-1].strtype);
 		  if (retval != 0) {
-		    yyerror("syntax error");
+		    conf_error("syntax error");
 		    YYABORT;
 		  }
 		;
     break;}
 case 14:
-#line 142 "../../amd/conf_parse.y"
+#line 125 "conf_parse.y"
 {
-		  if (yydebug)
-		    fprintf(stderr,"parse2: key=\"%s\", val=\"%s\"\n", yyvsp[-3].strtype, yyvsp[-1].strtype);
-		  retval = set_conf_kv(header_section, yyvsp[-3].strtype, yyvsp[-1].strtype);
+		  if (conf_debug)
+		    fprintf(stderr,"parse2: key=\"%s\", val=\"%s\"\n", conf_vsp[-3].strtype, conf_vsp[-1].strtype);
+		  retval = set_conf_kv(header_section, conf_vsp[-3].strtype, conf_vsp[-1].strtype);
 		  if (retval != 0) {
-		    yyerror("syntax error");
+		    conf_error("syntax error");
 		    YYABORT;
 		  }
 		;
     break;}
 case 15:
-#line 152 "../../amd/conf_parse.y"
+#line 135 "conf_parse.y"
 {
-		  if (yydebug)
-		    fprintf(stderr,"parse3: key=\"%s\", val=\"%s\"\n", yyvsp[-3].strtype, yyvsp[-1].strtype);
-		  retval = set_conf_kv(header_section, yyvsp[-3].strtype, yyvsp[-1].strtype);
+		  if (conf_debug)
+		    fprintf(stderr,"parse3: key=\"%s\", val=\"%s\"\n", conf_vsp[-3].strtype, conf_vsp[-1].strtype);
+		  retval = set_conf_kv(header_section, conf_vsp[-3].strtype, conf_vsp[-1].strtype);
 		  if (retval != 0) {
-		    yyerror("syntax error");
+		    conf_error("syntax error");
 		    YYABORT;
 		  }
 		;
     break;}
 }
    /* the action file gets copied in in place of this dollarsign */
-#line 543 "/usr/local/gnu/share/bison.simple"
+#line 543 "/usr/local/share/bison.simple"
 
-  yyvsp -= yylen;
-  yyssp -= yylen;
+  conf_vsp -= conf_len;
+  conf_ssp -= conf_len;
 #ifdef YYLSP_NEEDED
-  yylsp -= yylen;
+  conf_lsp -= conf_len;
 #endif
 
 #if YYDEBUG != 0
-  if (yydebug)
+  if (conf_debug)
     {
-      short *ssp1 = yyss - 1;
+      short *ssp1 = conf_ss - 1;
       fprintf (stderr, "state stack now");
-      while (ssp1 != yyssp)
+      while (ssp1 != conf_ssp)
 	fprintf (stderr, " %d", *++ssp1);
       fprintf (stderr, "\n");
     }
 #endif
 
-  *++yyvsp = yyval;
+  *++conf_vsp = conf_val;
 
 #ifdef YYLSP_NEEDED
-  yylsp++;
-  if (yylen == 0)
+  conf_lsp++;
+  if (conf_len == 0)
     {
-      yylsp->first_line = yylloc.first_line;
-      yylsp->first_column = yylloc.first_column;
-      yylsp->last_line = (yylsp-1)->last_line;
-      yylsp->last_column = (yylsp-1)->last_column;
-      yylsp->text = 0;
+      conf_lsp->first_line = conf_lloc.first_line;
+      conf_lsp->first_column = conf_lloc.first_column;
+      conf_lsp->last_line = (conf_lsp-1)->last_line;
+      conf_lsp->last_column = (conf_lsp-1)->last_column;
+      conf_lsp->text = 0;
     }
   else
     {
-      yylsp->last_line = (yylsp+yylen-1)->last_line;
-      yylsp->last_column = (yylsp+yylen-1)->last_column;
+      conf_lsp->last_line = (conf_lsp+conf_len-1)->last_line;
+      conf_lsp->last_column = (conf_lsp+conf_len-1)->last_column;
     }
 #endif
 
@@ -825,38 +809,38 @@ case 15:
      based on the state we popped back to
      and the rule number reduced by.  */
 
-  yyn = yyr1[yyn];
+  conf_n = conf_r1[conf_n];
 
-  yystate = yypgoto[yyn - YYNTBASE] + *yyssp;
-  if (yystate >= 0 && yystate <= YYLAST && yycheck[yystate] == *yyssp)
-    yystate = yytable[yystate];
+  conf_state = conf_pgoto[conf_n - YYNTBASE] + *conf_ssp;
+  if (conf_state >= 0 && conf_state <= YYLAST && conf_check[conf_state] == *conf_ssp)
+    conf_state = conf_table[conf_state];
   else
-    yystate = yydefgoto[yyn - YYNTBASE];
+    conf_state = conf_defgoto[conf_n - YYNTBASE];
 
-  goto yynewstate;
+  goto conf_newstate;
 
-yyerrlab:   /* here on detecting error */
+conf_errlab:   /* here on detecting error */
 
-  if (! yyerrstatus)
+  if (! conf_errstatus)
     /* If not already recovering from an error, report this error.  */
     {
-      ++yynerrs;
+      ++conf_nerrs;
 
 #ifdef YYERROR_VERBOSE
-      yyn = yypact[yystate];
+      conf_n = conf_pact[conf_state];
 
-      if (yyn > YYFLAG && yyn < YYLAST)
+      if (conf_n > YYFLAG && conf_n < YYLAST)
 	{
 	  int size = 0;
 	  char *msg;
 	  int x, count;
 
 	  count = 0;
-	  /* Start X at -yyn if nec to avoid negative indexes in yycheck.  */
-	  for (x = (yyn < 0 ? -yyn : 0);
-	       x < (sizeof(yytname) / sizeof(char *)); x++)
-	    if (yycheck[x + yyn] == x)
-	      size += strlen(yytname[x]) + 15, count++;
+	  /* Start X at -conf_n if nec to avoid negative indexes in conf_check.  */
+	  for (x = (conf_n < 0 ? -conf_n : 0);
+	       x < (sizeof(conf_tname) / sizeof(char *)); x++)
+	    if (conf_check[x + conf_n] == x)
+	      size += strlen(conf_tname[x]) + 15, count++;
 	  msg = (char *) malloc(size + 15);
 	  if (msg != 0)
 	    {
@@ -865,151 +849,151 @@ yyerrlab:   /* here on detecting error */
 	      if (count < 5)
 		{
 		  count = 0;
-		  for (x = (yyn < 0 ? -yyn : 0);
-		       x < (sizeof(yytname) / sizeof(char *)); x++)
-		    if (yycheck[x + yyn] == x)
+		  for (x = (conf_n < 0 ? -conf_n : 0);
+		       x < (sizeof(conf_tname) / sizeof(char *)); x++)
+		    if (conf_check[x + conf_n] == x)
 		      {
 			strcat(msg, count == 0 ? ", expecting `" : " or `");
-			strcat(msg, yytname[x]);
+			strcat(msg, conf_tname[x]);
 			strcat(msg, "'");
 			count++;
 		      }
 		}
-	      yyerror(msg);
+	      conf_error(msg);
 	      free(msg);
 	    }
 	  else
-	    yyerror ("parse error; also virtual memory exceeded");
+	    conf_error ("parse error; also virtual memory exceeded");
 	}
       else
 #endif /* YYERROR_VERBOSE */
-	yyerror("parse error");
+	conf_error("parse error");
     }
 
-  goto yyerrlab1;
-yyerrlab1:   /* here on error raised explicitly by an action */
+  goto conf_errlab1;
+conf_errlab1:   /* here on error raised explicitly by an action */
 
-  if (yyerrstatus == 3)
+  if (conf_errstatus == 3)
     {
       /* if just tried and failed to reuse lookahead token after an error, discard it.  */
 
       /* return failure if at end of input */
-      if (yychar == YYEOF)
+      if (conf_char == YYEOF)
 	YYABORT;
 
 #if YYDEBUG != 0
-      if (yydebug)
-	fprintf(stderr, "Discarding token %d (%s).\n", yychar, yytname[yychar1]);
+      if (conf_debug)
+	fprintf(stderr, "Discarding token %d (%s).\n", conf_char, conf_tname[conf_char1]);
 #endif
 
-      yychar = YYEMPTY;
+      conf_char = YYEMPTY;
     }
 
   /* Else will try to reuse lookahead token
      after shifting the error token.  */
 
-  yyerrstatus = 3;		/* Each real token shifted decrements this */
+  conf_errstatus = 3;		/* Each real token shifted decrements this */
 
-  goto yyerrhandle;
+  goto conf_errhandle;
 
-yyerrdefault:  /* current state does not do anything special for the error token. */
+conf_errdefault:  /* current state does not do anything special for the error token. */
 
 #if 0
   /* This is wrong; only states that explicitly want error tokens
      should shift them.  */
-  yyn = yydefact[yystate];  /* If its default is to accept any token, ok.  Otherwise pop it.*/
-  if (yyn) goto yydefault;
+  conf_n = conf_defact[conf_state];  /* If its default is to accept any token, ok.  Otherwise pop it.*/
+  if (conf_n) goto conf_default;
 #endif
 
-yyerrpop:   /* pop the current state because it cannot handle the error token */
+conf_errpop:   /* pop the current state because it cannot handle the error token */
 
-  if (yyssp == yyss) YYABORT;
-  yyvsp--;
-  yystate = *--yyssp;
+  if (conf_ssp == conf_ss) YYABORT;
+  conf_vsp--;
+  conf_state = *--conf_ssp;
 #ifdef YYLSP_NEEDED
-  yylsp--;
+  conf_lsp--;
 #endif
 
 #if YYDEBUG != 0
-  if (yydebug)
+  if (conf_debug)
     {
-      short *ssp1 = yyss - 1;
+      short *ssp1 = conf_ss - 1;
       fprintf (stderr, "Error: state stack now");
-      while (ssp1 != yyssp)
+      while (ssp1 != conf_ssp)
 	fprintf (stderr, " %d", *++ssp1);
       fprintf (stderr, "\n");
     }
 #endif
 
-yyerrhandle:
+conf_errhandle:
 
-  yyn = yypact[yystate];
-  if (yyn == YYFLAG)
-    goto yyerrdefault;
+  conf_n = conf_pact[conf_state];
+  if (conf_n == YYFLAG)
+    goto conf_errdefault;
 
-  yyn += YYTERROR;
-  if (yyn < 0 || yyn > YYLAST || yycheck[yyn] != YYTERROR)
-    goto yyerrdefault;
+  conf_n += YYTERROR;
+  if (conf_n < 0 || conf_n > YYLAST || conf_check[conf_n] != YYTERROR)
+    goto conf_errdefault;
 
-  yyn = yytable[yyn];
-  if (yyn < 0)
+  conf_n = conf_table[conf_n];
+  if (conf_n < 0)
     {
-      if (yyn == YYFLAG)
-	goto yyerrpop;
-      yyn = -yyn;
-      goto yyreduce;
+      if (conf_n == YYFLAG)
+	goto conf_errpop;
+      conf_n = -conf_n;
+      goto conf_reduce;
     }
-  else if (yyn == 0)
-    goto yyerrpop;
+  else if (conf_n == 0)
+    goto conf_errpop;
 
-  if (yyn == YYFINAL)
+  if (conf_n == YYFINAL)
     YYACCEPT;
 
 #if YYDEBUG != 0
-  if (yydebug)
+  if (conf_debug)
     fprintf(stderr, "Shifting error token, ");
 #endif
 
-  *++yyvsp = yylval;
+  *++conf_vsp = conf_lval;
 #ifdef YYLSP_NEEDED
-  *++yylsp = yylloc;
+  *++conf_lsp = conf_lloc;
 #endif
 
-  yystate = yyn;
-  goto yynewstate;
+  conf_state = conf_n;
+  goto conf_newstate;
 
- yyacceptlab:
+ conf_acceptlab:
   /* YYACCEPT comes here.  */
-  if (yyfree_stacks)
+  if (conf_free_stacks)
     {
-      free (yyss);
-      free (yyvs);
+      free (conf_ss);
+      free (conf_vs);
 #ifdef YYLSP_NEEDED
-      free (yyls);
+      free (conf_ls);
 #endif
     }
   return 0;
 
- yyabortlab:
+ conf_abortlab:
   /* YYABORT comes here.  */
-  if (yyfree_stacks)
+  if (conf_free_stacks)
     {
-      free (yyss);
-      free (yyvs);
+      free (conf_ss);
+      free (conf_vs);
 #ifdef YYLSP_NEEDED
-      free (yyls);
+      free (conf_ls);
 #endif
     }
   return 1;
 }
-#line 165 "../../amd/conf_parse.y"
+#line 148 "conf_parse.y"
 
 
 static int
-yyerror(const char *s)
+conf_error(const char *s)
 {
   fprintf(stderr, "AMDCONF: %s on line %d (section %s)\n",
-	  s, yylineno,
+	  s, aconf_lineno,
 	  (header_section ? header_section : "null"));
   exit(1);
   return 1;	/* to full compilers that insist on a return statement */
