@@ -1,32 +1,60 @@
 
+#define PACKAGE_NAME "am-utils"
+#define PACKAGE_TARNAME "am-utils"
+#define PACKAGE_VERSION "6.2a2"
+#define PACKAGE_STRING "am-utils 6.2a2"
+#define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define HOST_CPU "sparc"
 #define HOST_VENDOR "sun"
-#define HOST_OS "solaris2.7"
+#define HOST_OS "solaris2.8"
 #define HOST_OS_NAME "solaris2"
-#define HOST_OS_VERSION "2.7"
+#define HOST_OS_VERSION "2.8"
 #define HOST_ARCH "sun4"
-#define HOST_NAME "shekel.mcl.cs.columbia.edu"
+#define DISTRO_NAME "none"
+#define HOST_NAME "a-solaris8.fsl.cs.sunysb.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Thu Jul 19 23:09:12 EDT 2001"
+#define CONFIG_DATE "Thu May 11 11:28:14 EDT 2006"
+#define PACKAGE_NAME "am-utils"
+#define PACKAGE_VERSION "6.2a2"
+#define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define PACKAGE "am-utils"
-#define VERSION "6.0.8s1"
-#define PACKAGE "am-utils"
-#define VERSION "6.0.8s1"
+#define VERSION "6.2a2"
 #define DEBUG 1
-#define HOST_HEADER_VERSION "2.7"
+#define STDC_HEADERS 1
+#define HAVE_SYS_TYPES_H 1
+#define HAVE_SYS_STAT_H 1
+#define HAVE_STDLIB_H 1
+#define HAVE_STRING_H 1
+#define HAVE_MEMORY_H 1
+#define HAVE_STRINGS_H 1
+#define HAVE_INTTYPES_H 1
+#define HAVE_UNISTD_H 1
+#define HAVE_DLFCN_H 1
+#ifdef __cplusplus
+#include <stdlib.h>
+#endif
+#define HOST_HEADER_VERSION "2.8"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
+#define HAVE_LIBRESOLV 1
 #define HAVE_LIBLDAP 1
+#define HAVE_LDAP_ENABLE_CACHE 1
 #define HAVE_LIBRT 1
-#define HAVE_ALLOCA_H 1
-#define HAVE_ALLOCA 1
-#define STDC_HEADERS 1
+#define HAVE_UNISTD_H 1
+#define HAVE_FORK 1
+#define HAVE_VFORK 1
+#define HAVE_WORKING_VFORK 1
+#define HAVE_WORKING_FORK 1
+#define GETPGRP_VOID 1
+#define SETPGRP_VOID 1
+#define HAVE___RPC_GET_LOCAL_UID 1
 #define HAVE___SETERR_REPLY 1
 #define HAVE_BCMP 1
 #define HAVE_BCOPY 1
 #define HAVE_BZERO 1
 #define HAVE_CLNT_CREATE 1
-#define HAVE_CLNT_CREATE_TIMED 1
+#define HAVE_CLNT_CREATE_VERS 1
+#define HAVE_CLNT_CREATE_VERS_TIMED 1
 #define HAVE_CLNT_SPCREATEERROR 1
 #define HAVE_CLOCK_GETTIME 1
 #define HAVE_GET_MYADDRESS 1
@@ -37,13 +65,14 @@
 #define HAVE_GETPAGESIZE 1
 #define HAVE_GETTIMEOFDAY 1
 #define HAVE_HASMNTOPT 1
-#define HAVE_LDAP_OPEN 1
+#define HAVE_MADVISE 1
 #define HAVE_MEMCMP 1
 #define HAVE_MEMCPY 1
 #define HAVE_MEMMOVE 1
 #define HAVE_MEMSET 1
 #define HAVE_MKDIR 1
 #define HAVE_MKSTEMP 1
+#define HAVE_MLOCKALL 1
 #define HAVE_MOUNT 1
 #define HAVE_PLOCK 1
 #define HAVE_REGCOMP 1
@@ -55,12 +84,17 @@
 #define HAVE_SETSID 1
 #define HAVE_SIGACTION 1
 #define HAVE_SIGNAL 1
+#define HAVE_SIGSUSPEND 1
 #define HAVE_SOCKET 1
+#define HAVE_STATFS 1
+#define HAVE_STATVFS 1
+#define HAVE_STRCASECMP 1
 #define HAVE_STRCHR 1
 #define HAVE_STRCSPN 1
-#define HAVE_STRCASECMP 1
 #define HAVE_STRDUP 1
 #define HAVE_STRERROR 1
+#define HAVE_STRLCAT 1
+#define HAVE_STRLCPY 1
 #define HAVE_STRSPN 1
 #define HAVE_STRSTR 1
 #define HAVE_SVC_GETREQ 1
@@ -69,6 +103,7 @@
 #define HAVE_SYSLOG 1
 #define HAVE_UNAME 1
 #define HAVE_UMOUNT 1
+#define HAVE_UMOUNT2 1
 #define HAVE_VFORK 1
 #define HAVE_VSNPRINTF 1
 #define HAVE_WAIT3 1
@@ -77,6 +112,9 @@
 #define HAVE_HASMNTOPT 1
 #define HAVE_STRCASECMP 1
 #define HAVE_STRDUP 1
+#define HAVE_STRERROR 1
+#define HAVE_STRLCAT 1
+#define HAVE_STRLCPY 1
 #define HAVE_STRSTR 1
 #define HAVE_UALARM 1
 #define HAVE_XDR_DIRPATH 1
@@ -88,7 +126,6 @@
 #define HAVE_XDR_GROUPS 1
 #define HAVE_XDR_MOUNTBODY 1
 #define HAVE_XDR_MOUNTLIST 1
-#define HAVE_XDR_MOUNTRES3 1
 #define HAVE_XDR_NAME 1
 #define HAVE_XDR_POINTER 1
 #define HAVE_DIRENT_H 1
@@ -110,6 +147,7 @@
 #define HAVE_RPC_RPC_H 1
 #define HAVE_RPC_TYPES_H 1
 #define HAVE_RPC_XDR_H 1
+#define HAVE_RPCSVC_AUTOFS_PROT_H 1
 #define HAVE_RPCSVC_MOUNT_H 1
 #define HAVE_RPCSVC_NFS_PROT_H 1
 #define HAVE_RPCSVC_NIS_H 1
@@ -126,6 +164,7 @@
 #define HAVE_SYS_FSTYP_H 1
 #define HAVE_SYS_IOCTL_H 1
 #define HAVE_SYS_LOCK_H 1
+#define HAVE_SYS_MMAN_H 1
 #define HAVE_SYS_MNTENT_H 1
 #define HAVE_SYS_MNTTAB_H 1
 #define HAVE_SYS_MOUNT_H 1
@@ -139,6 +178,7 @@
 #define HAVE_SYS_SOCKIO_H 1
 #define HAVE_SYS_STAT_H 1
 #define HAVE_SYS_STATFS_H 1
+#define HAVE_SYS_STATVFS_H 1
 #define HAVE_SYS_SYSCALL_H 1
 #define HAVE_SYS_SYSLOG_H 1
 #define HAVE_SYS_TIME_H 1
@@ -153,9 +193,8 @@
 #define HAVE_ERRNO_H 1
 #define HAVE_FCNTL_H 1
 #define HAVE_GRP_H 1
-#define HAVE_LBER_H 1
-#define HAVE_LDAP_H 1
 #define HAVE_LIBGEN_H 1
+#define HAVE_LIMITS_H 1
 #define HAVE_MALLOC_H 1
 #define HAVE_MEMORY_H 1
 #define HAVE_NDBM_H 1
@@ -174,18 +213,22 @@
 #define HAVE_STRING_H 1
 #define HAVE_STRINGS_H 1
 #define HAVE_SYSLOG_H 1
+#define HAVE_TCPD_H 1
 #define HAVE_TIME_H 1
 #define HAVE_TIUSER_H 1
-#define HAVE_VARARGS_H 1
 #define HAVE_UNISTD_H 1
+#define HAVE_LBER_H 1
+#define HAVE_LDAP_H 1
+#define NEW_DBM_H "ndbm.h"
 #define TIME_WITH_SYS_TIME 1
-#define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_sunos5_7.h"
+#define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_sunos5_8.h"
 #define HAVE_STRUCT_MNTTAB 1
+#define HAVE_BAD_HASMNTOPT 1
 #define HAVE_STRUCT_NFS_ARGS 1
 #define nfs_args_t struct nfs_args
 #define NFS_FH_FIELD fh
 #define am_nfs_fh nfs_fh
-#define am_nfs_fh3 nfs_fh3
+#define HAVE_FS_NFS3 1
 #define GETGROUPS_T gid_t
 #define RETSIGTYPE void
 #define HAVE_FHANDLE 1
@@ -198,11 +241,11 @@
 #define autofs_args_t struct autofs_args
 #define cachefs_args_t struct cachefs_mountargs
 #define pcfs_args_t struct pcfs_args
-#define tmpfs_args_t struct tmpfs_args
 #define ufs_args_t struct ufs_args
 #define XDRPROC_T_TYPE xdrproc_t
 #define WORDS_BIGENDIAN 1
 #define voidp void *
+#define HAVE_C99_VARARGS_MACROS 1
 #define HAVE_EXTERN_OPTARG 1
 #define HAVE_EXTERN_CLNT_SPCREATEERROR 1
 #define HAVE_EXTERN_CLNT_SPERRNO 1
@@ -218,35 +261,48 @@
 #define HAVE_EXTERN_SBRK 1
 #define HAVE_EXTERN_SETEUID 1
 #define HAVE_EXTERN_SETITIMER 1
+#define HAVE_EXTERN_SLEEP 1
 #define HAVE_EXTERN_STRCASECMP 1
 #define HAVE_EXTERN_STRDUP 1
+#define HAVE_EXTERN_STRLCAT 1
+#define HAVE_EXTERN_STRLCPY 1
 #define HAVE_EXTERN_STRSTR 1
 #define HAVE_EXTERN_UALARM 1
 #define HAVE_EXTERN_USLEEP 1
 #define HAVE_EXTERN_WAIT3 1
 #define HAVE_EXTERN_VSNPRINTF 1
+#define HAVE_EXTERN_XDR_CALLMSG 1
+#define HAVE_EXTERN_LDAP_ENABLE_CACHE 1
 #define HAVE_LONG_FILE_NAMES 1
+#define HAVE_UNISTD_H 1
 #define HAVE_TRANSPORT_TYPE_TLI 1
-#define HAVE_FIELD_MNTENT_T_MNT_TIME 1
-#define HAVE_FIELD_MNTENT_T_MNT_TIME_STRING 1
-#define HAVE_FIELD_PCFS_ARGS_T_DSTTIME 1
-#define HAVE_FIELD_PCFS_ARGS_T_SECONDSWEST 1
-#define HAVE_FIELD_UFS_ARGS_T_FLAGS 1
-#define HAVE_FIELD_STRUCT_FHSTATUS_FHS_FH 1
-#define HAVE_FIELD_NFS_ARGS_T_ACDIRMIN 1
-#define HAVE_FIELD_NFS_ARGS_T_ACREGMIN 1
-#define HAVE_FIELD_STRUCT_IFREQ_IFR_ADDR 1
+#define HAVE_FD_SET_FDS_BITS 1
+#define HAVE_MNTENT_T_MNT_TIME 1
+#define HAVE_MNTENT_T_MNT_TIME_STRING 1
+#define HAVE_PCFS_ARGS_T_DSTTIME 1
+#define HAVE_PCFS_ARGS_T_SECONDSWEST 1
+#define HAVE_UFS_ARGS_T_FLAGS 1
+#define HAVE_STRUCT_FHSTATUS_FHS_FH 1
+#define HAVE_NFS_ARGS_T_ACDIRMIN 1
+#define HAVE_NFS_ARGS_T_ACDIRMAX 1
+#define HAVE_NFS_ARGS_T_ACREGMIN 1
+#define HAVE_NFS_ARGS_T_ACREGMAX 1
+#define HAVE_STRUCT_IFREQ_IFR_ADDR 1
+#define HAVE_AUTOFS_ARGS_T_ADDR 1
 #define HAVE_MAP_FILE 1
+#define HAVE_MAP_SUN 1
+#define HAVE_MAP_EXEC 1
 #define HAVE_MAP_LDAP 1
+#define HAVE_DBM_OPEN 1
 #define HAVE_MAP_NDBM 1
 #define HAVE_MAP_NIS 1
 #define HAVE_MAP_NISPLUS 1
 #define HAVE_MAP_PASSWD 1
 #define HAVE_MAP_UNION 1
+#define HAVE_FS_AUTOFS 1
 #define HAVE_FS_CDFS 1
 #define HAVE_FS_LOFS 1
 #define HAVE_FS_NFS 1
-#define HAVE_FS_NFS3 1
 #define HAVE_FS_PCFS 1
 #define HAVE_FS_TMPFS 1
 #define HAVE_FS_UFS 1
@@ -256,7 +312,6 @@
 #define HAVE_AMU_FS_DIRECT 1
 #define HAVE_AMU_FS_TOPLVL 1
 #define HAVE_AMU_FS_ERROR 1
-#define HAVE_AMU_FS_INHERIT 1
 #define HAVE_AMU_FS_PROGRAM 1
 #define HAVE_AMU_FS_LINK 1
 #define HAVE_AMU_FS_LINKX 1
@@ -268,7 +323,7 @@
 #define MOUNT_TYPE_NFS3 MNTTYPE_NFS3
 #define MOUNT_TYPE_UFS MNTTYPE_UFS
 #define MOUNT_TYPE_CDFS MNTTYPE_HSFS
-#define MOUNT_TYPE_PCFS MNTTYPE_PC
+#define MOUNT_TYPE_PCFS MNTTYPE_PCFS
 #define MOUNT_TYPE_TMPFS MNTTYPE_TMPFS
 #define MOUNT_TYPE_LOFS MNTTYPE_LOFS
 #define MOUNT_TYPE_AUTOFS MNTTYPE_AUTOFS
@@ -277,7 +332,7 @@
 #define MNTTAB_TYPE_NFS3 "nfs3"
 #define MNTTAB_TYPE_UFS "ufs"
 #define MNTTAB_TYPE_CDFS "hsfs"
-#define MNTTAB_TYPE_PCFS "pc"
+#define MNTTAB_TYPE_PCFS "pcfs"
 #define MNTTAB_TYPE_TMPFS "tmpfs"
 #define MNTTAB_TYPE_LOFS "lofs"
 #define MNTTAB_TYPE_AUTOFS "autofs"
@@ -299,6 +354,7 @@
 #define MNTTAB_OPT_PORT "port"
 #define MNTTAB_OPT_POSIX "posix"
 #define MNTTAB_OPT_PROTO "proto"
+#define MNTTAB_OPT_PUBLIC "public"
 #define MNTTAB_OPT_RETRANS "retrans"
 #define MNTTAB_OPT_RETRY "retry"
 #define MNTTAB_OPT_RO "ro"
@@ -310,7 +366,9 @@
 #define MNTTAB_OPT_VERS "vers"
 #define MNTTAB_OPT_WSIZE "wsize"
 #define MNT2_GEN_OPT_DATA 0x4
+#define MNT2_GEN_OPT_FORCE 0x400
 #define MNT2_GEN_OPT_FSS 0x2
+#define MNT2_GEN_OPT_NOMNTTAB 0x800
 #define MNT2_GEN_OPT_NOSUID 0x10
 #define MNT2_GEN_OPT_OPTIONSTR 0x100
 #define MNT2_GEN_OPT_OVERLAY 0x80
@@ -332,6 +390,5 @@
 #define MNT2_NFS_OPT_TIMEO 0x8
 #define MNT2_NFS_OPT_WSIZE 0x2
 #define HIDE_MOUNT_TYPE "nfs"
-#define MOUNT_TABLE_ON_FILE 1
 #define MNTTAB_FILE_NAME "/etc/mnttab"
 #define REINSTALL_SIGNAL_HANDLER 1
