@@ -33,7 +33,7 @@
 #define	tSEL	283
 #define	tSTR	284
 
-#line 45 "../../fsinfo/fsi_gram.y"
+#line 44 "../../fsinfo/fsi_gram.y"
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -42,25 +42,9 @@
 #include <fsi_data.h>
 #include <fsinfo.h>
 
-/* AIX requires this to be the first thing in the file. */
-#ifndef __GNUC__
-# if HAVE_ALLOCA_H
-#  include <alloca.h>
-# else /* not HAVE_ALLOCA_H */
-#  ifdef _AIX
-#pragma alloca
-#  else /* not _AIX */
-#   ifndef alloca
-  /* predefined by HP cc +Olibcalls */
-voidp alloca();
-#   endif /* not alloca */
-#  endif /* not _AIX */
-# endif /* not HAVE_ALLOCA_H */
-#endif /* not __GNUC__ */
-
 extern qelem *list_of_hosts, *list_of_automounts;
 
-#line 72 "../../fsinfo/fsi_gram.y"
+#line 55 "../../fsinfo/fsi_gram.y"
 typedef union {
 	auto_tree *a;
 	disk_fs *d;
@@ -158,12 +142,12 @@ static const short yyrhs[] = {    -1,
 
 #if YYDEBUG != 0
 static const short yyrline[] = { 0,
-   126,   130,   134,   144,   148,   153,   157,   162,   166,   172,
-   175,   178,   181,   184,   188,   192,   194,   196,   205,   214,
-   218,   222,   226,   230,   248,   252,   267,   271,   274,   277,
-   280,   283,   286,   289,   292,   305,   309,   319,   330,   340,
-   352,   356,   369,   373,   376,   379,   382,   391,   395,   414,
-   418,   421,   424,   427,   430,   433
+   109,   113,   117,   127,   131,   136,   140,   145,   149,   155,
+   158,   161,   164,   167,   171,   175,   177,   179,   188,   197,
+   201,   205,   209,   213,   231,   235,   250,   254,   257,   260,
+   263,   266,   269,   272,   275,   288,   292,   302,   313,   323,
+   335,   339,   352,   356,   359,   362,   365,   374,   378,   397,
+   401,   404,   407,   410,   413,   416
 };
 #endif
 
@@ -277,7 +261,7 @@ static const short yycheck[] = {     1,
     19,     7
 };
 /* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
-#line 3 "/usr/local/gnu/share/bison.simple"
+#line 3 "/usr/local/share/bison.simple"
 /* This file comes from bison-1.28.  */
 
 /* Skeleton output parser for bison,
@@ -491,7 +475,7 @@ __yy_memcpy (char *to, char *from, unsigned int count)
 #endif
 #endif
 
-#line 217 "/usr/local/gnu/share/bison.simple"
+#line 217 "/usr/local/share/bison.simple"
 
 /* The user can define YYPARSE_PARAM as the name of an argument to be passed
    into yyparse.  The argument should have type void *.
@@ -820,84 +804,84 @@ yyreduce:
   switch (yyn) {
 
 case 1:
-#line 128 "../../fsinfo/fsi_gram.y"
+#line 111 "../../fsinfo/fsi_gram.y"
 { yyval.q = new_que(); ;
     break;}
 case 2:
-#line 131 "../../fsinfo/fsi_gram.y"
+#line 114 "../../fsinfo/fsi_gram.y"
 { if (yyvsp[0].h) ins_que((qelem *) yyvsp[0].h, list_of_hosts->q_back);
 	    yyval.q = yyvsp[-1].q; ;
     break;}
 case 3:
-#line 135 "../../fsinfo/fsi_gram.y"
+#line 118 "../../fsinfo/fsi_gram.y"
 { if (yyvsp[0].a) ins_que((qelem *) yyvsp[0].a, list_of_automounts->q_back);
 	    yyval.q = yyvsp[-1].q; ;
     break;}
 case 4:
-#line 146 "../../fsinfo/fsi_gram.y"
+#line 129 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-2].h; yyval.h->h_disk_fs = yyvsp[-1].q; yyval.h->h_mount = yyvsp[0].q; ;
     break;}
 case 5:
-#line 149 "../../fsinfo/fsi_gram.y"
+#line 132 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-2].h; yyval.h->h_disk_fs = yyvsp[-1].q; yyval.h->h_mount = yyvsp[0].q; ;
     break;}
 case 6:
-#line 155 "../../fsinfo/fsi_gram.y"
+#line 138 "../../fsinfo/fsi_gram.y"
 { yyval.h = new_host(); set_host(yyval.h, HF_HOST, yyvsp[0].s); ;
     break;}
 case 7:
-#line 158 "../../fsinfo/fsi_gram.y"
+#line 141 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-2].h; set_host(yyval.h, HF_HOST, yyvsp[0].s); ;
     break;}
 case 8:
-#line 164 "../../fsinfo/fsi_gram.y"
+#line 147 "../../fsinfo/fsi_gram.y"
 { yyval.h = new_host(); ;
     break;}
 case 9:
-#line 167 "../../fsinfo/fsi_gram.y"
+#line 150 "../../fsinfo/fsi_gram.y"
 { if (yyvsp[-1].e) {
 		yyvsp[-1].e->e_if = yyvsp[-3].s;
 		yyval.h = yyvsp[-5].h; set_host(yyval.h, HF_ETHER, (char *) yyvsp[-1].e); }
 	  ;
     break;}
 case 10:
-#line 173 "../../fsinfo/fsi_gram.y"
+#line 156 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-2].h; set_host(yyval.h, HF_CONFIG, yyvsp[0].s); ;
     break;}
 case 11:
-#line 176 "../../fsinfo/fsi_gram.y"
+#line 159 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-3].h; set_host(yyval.h, HF_ARCH, yyvsp[0].s); ;
     break;}
 case 12:
-#line 179 "../../fsinfo/fsi_gram.y"
+#line 162 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-3].h; set_host(yyval.h, HF_OS, yyvsp[0].s); ;
     break;}
 case 13:
-#line 182 "../../fsinfo/fsi_gram.y"
+#line 165 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-3].h; set_host(yyval.h, HF_CLUSTER, yyvsp[0].s); ;
     break;}
 case 14:
-#line 185 "../../fsinfo/fsi_gram.y"
+#line 168 "../../fsinfo/fsi_gram.y"
 { yyerror("unknown host attribute"); ;
     break;}
 case 15:
-#line 190 "../../fsinfo/fsi_gram.y"
+#line 173 "../../fsinfo/fsi_gram.y"
 { yyval.e = new_ether_if(); ;
     break;}
 case 16:
-#line 193 "../../fsinfo/fsi_gram.y"
+#line 176 "../../fsinfo/fsi_gram.y"
 { yyval.e = yyvsp[-3].e; set_ether_if(yyval.e, EF_INADDR, yyvsp[0].s); ;
     break;}
 case 17:
-#line 195 "../../fsinfo/fsi_gram.y"
+#line 178 "../../fsinfo/fsi_gram.y"
 { yyval.e = yyvsp[-3].e; set_ether_if(yyval.e, EF_NETMASK, yyvsp[0].s); ;
     break;}
 case 18:
-#line 197 "../../fsinfo/fsi_gram.y"
+#line 180 "../../fsinfo/fsi_gram.y"
 { yyval.e = yyvsp[-3].e; set_ether_if(yyval.e, EF_HWADDR, yyvsp[0].s); ;
     break;}
 case 19:
-#line 207 "../../fsinfo/fsi_gram.y"
+#line 190 "../../fsinfo/fsi_gram.y"
 { if (yyvsp[0].q) {
 		yyval.a = new_auto_tree(yyvsp[-1].s, yyvsp[0].q);
 	    } else {
@@ -906,23 +890,23 @@ case 19:
 	  ;
     break;}
 case 20:
-#line 215 "../../fsinfo/fsi_gram.y"
+#line 198 "../../fsinfo/fsi_gram.y"
 { yyval.a = 0; ;
     break;}
 case 21:
-#line 220 "../../fsinfo/fsi_gram.y"
+#line 203 "../../fsinfo/fsi_gram.y"
 { yyval.s = strdup(""); ;
     break;}
 case 22:
-#line 223 "../../fsinfo/fsi_gram.y"
+#line 206 "../../fsinfo/fsi_gram.y"
 { yyval.s = yyvsp[0].s; ;
     break;}
 case 23:
-#line 228 "../../fsinfo/fsi_gram.y"
+#line 211 "../../fsinfo/fsi_gram.y"
 { yyval.q = 0; ;
     break;}
 case 24:
-#line 231 "../../fsinfo/fsi_gram.y"
+#line 214 "../../fsinfo/fsi_gram.y"
 { if (yyvsp[0].d) {
 		if (yyvsp[-1].q)
 			yyval.q = yyvsp[-1].q;
@@ -935,55 +919,55 @@ case 24:
 	  ;
     break;}
 case 25:
-#line 250 "../../fsinfo/fsi_gram.y"
+#line 233 "../../fsinfo/fsi_gram.y"
 { yyvsp[-1].d->d_dev = yyvsp[-3].s; yyval.d = yyvsp[-1].d; ;
     break;}
 case 26:
-#line 253 "../../fsinfo/fsi_gram.y"
-{ yyval.d = (disk_fs *) 0; ;
+#line 236 "../../fsinfo/fsi_gram.y"
+{ yyval.d = (disk_fs *) NULL; ;
     break;}
 case 27:
-#line 269 "../../fsinfo/fsi_gram.y"
+#line 252 "../../fsinfo/fsi_gram.y"
 { yyval.d = new_disk_fs(); ;
     break;}
 case 28:
-#line 272 "../../fsinfo/fsi_gram.y"
+#line 255 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_FSTYPE, yyvsp[0].s); ;
     break;}
 case 29:
-#line 275 "../../fsinfo/fsi_gram.y"
+#line 258 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_OPTS, yyvsp[0].s); ;
     break;}
 case 30:
-#line 278 "../../fsinfo/fsi_gram.y"
+#line 261 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_PASSNO, yyvsp[0].s); ;
     break;}
 case 31:
-#line 281 "../../fsinfo/fsi_gram.y"
+#line 264 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_FREQ, yyvsp[0].s); ;
     break;}
 case 32:
-#line 284 "../../fsinfo/fsi_gram.y"
+#line 267 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-2].d; set_disk_fs(yyval.d, DF_MOUNT, (char *) yyvsp[0].q); ;
     break;}
 case 33:
-#line 287 "../../fsinfo/fsi_gram.y"
+#line 270 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_DUMPSET, yyvsp[0].s); ;
     break;}
 case 34:
-#line 290 "../../fsinfo/fsi_gram.y"
+#line 273 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_LOG, yyvsp[0].s); ;
     break;}
 case 35:
-#line 293 "../../fsinfo/fsi_gram.y"
+#line 276 "../../fsinfo/fsi_gram.y"
 { yyerror("unknown filesystem attribute"); ;
     break;}
 case 36:
-#line 307 "../../fsinfo/fsi_gram.y"
+#line 290 "../../fsinfo/fsi_gram.y"
 { yyval.q = 0; ;
     break;}
 case 37:
-#line 310 "../../fsinfo/fsi_gram.y"
+#line 293 "../../fsinfo/fsi_gram.y"
 { automount *a = new_automount(yyvsp[-3].s);
 	    a->a_volname = yyvsp[0].s;
 	    a->a_opts = yyvsp[-2].s;
@@ -995,7 +979,7 @@ case 37:
 	  ;
     break;}
 case 38:
-#line 320 "../../fsinfo/fsi_gram.y"
+#line 303 "../../fsinfo/fsi_gram.y"
 { automount *a = new_automount(yyvsp[-3].s);
             a->a_hardwiredfs = yyvsp[0].s;
             a->a_opts = yyvsp[-2].s;
@@ -1007,7 +991,7 @@ case 38:
           ;
     break;}
 case 39:
-#line 331 "../../fsinfo/fsi_gram.y"
+#line 314 "../../fsinfo/fsi_gram.y"
 { automount *a = new_automount(yyvsp[-2].s);
 	    a->a_symlink = yyvsp[0].s;
 	    if (yyvsp[-3].q)
@@ -1018,7 +1002,7 @@ case 39:
 	  ;
     break;}
 case 40:
-#line 341 "../../fsinfo/fsi_gram.y"
+#line 324 "../../fsinfo/fsi_gram.y"
 { automount *a = new_automount(yyvsp[-4].s);
 	    a->a_mount = yyvsp[-1].q;
 	    a->a_opts = yyvsp[-3].s;
@@ -1030,11 +1014,11 @@ case 40:
 	  ;
     break;}
 case 41:
-#line 354 "../../fsinfo/fsi_gram.y"
+#line 337 "../../fsinfo/fsi_gram.y"
 { yyval.q = 0; ;
     break;}
 case 42:
-#line 357 "../../fsinfo/fsi_gram.y"
+#line 340 "../../fsinfo/fsi_gram.y"
 { yyvsp[-2].m->m_mount = yyvsp[-1].q;
 	    yyvsp[-2].m->m_name = yyvsp[-4].s;
 	    if (yyvsp[-4].s[0] != '/' && yyvsp[-4].s[1] && strchr(yyvsp[-4].s+1, '/'))
@@ -1047,31 +1031,31 @@ case 42:
 	  ;
     break;}
 case 43:
-#line 371 "../../fsinfo/fsi_gram.y"
+#line 354 "../../fsinfo/fsi_gram.y"
 { yyval.m = new_mount(); ;
     break;}
 case 44:
-#line 374 "../../fsinfo/fsi_gram.y"
+#line 357 "../../fsinfo/fsi_gram.y"
 { yyval.m = yyvsp[-2].m; set_mount(yyval.m, DM_EXPORTFS, yyvsp[0].s); ;
     break;}
 case 45:
-#line 377 "../../fsinfo/fsi_gram.y"
+#line 360 "../../fsinfo/fsi_gram.y"
 { yyval.m = yyvsp[-2].m; set_mount(yyval.m, DM_VOLNAME, yyvsp[0].s); ;
     break;}
 case 46:
-#line 380 "../../fsinfo/fsi_gram.y"
+#line 363 "../../fsinfo/fsi_gram.y"
 { yyval.m = yyvsp[-2].m; set_mount(yyval.m, DM_SEL, yyvsp[0].s); ;
     break;}
 case 47:
-#line 383 "../../fsinfo/fsi_gram.y"
+#line 366 "../../fsinfo/fsi_gram.y"
 { yyerror("unknown directory attribute"); ;
     break;}
 case 48:
-#line 393 "../../fsinfo/fsi_gram.y"
+#line 376 "../../fsinfo/fsi_gram.y"
 { yyval.q = 0; ;
     break;}
 case 49:
-#line 396 "../../fsinfo/fsi_gram.y"
+#line 379 "../../fsinfo/fsi_gram.y"
 { set_fsmount(yyvsp[0].f, FM_VOLNAME, yyvsp[-1].s);
 	    if (yyvsp[-3].q)
 		yyval.q = yyvsp[-3].q;
@@ -1081,36 +1065,36 @@ case 49:
 	    ;
     break;}
 case 50:
-#line 416 "../../fsinfo/fsi_gram.y"
+#line 399 "../../fsinfo/fsi_gram.y"
 { yyval.f = new_fsmount(); ;
     break;}
 case 51:
-#line 419 "../../fsinfo/fsi_gram.y"
+#line 402 "../../fsinfo/fsi_gram.y"
 { yyval.f = yyvsp[-1].f; set_fsmount(yyval.f, FM_DIRECT, ""); ;
     break;}
 case 52:
-#line 422 "../../fsinfo/fsi_gram.y"
+#line 405 "../../fsinfo/fsi_gram.y"
 { yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_LOCALNAME, yyvsp[0].s); ;
     break;}
 case 53:
-#line 425 "../../fsinfo/fsi_gram.y"
+#line 408 "../../fsinfo/fsi_gram.y"
 { yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_FROM, yyvsp[0].s); ;
     break;}
 case 54:
-#line 428 "../../fsinfo/fsi_gram.y"
+#line 411 "../../fsinfo/fsi_gram.y"
 { yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_FSTYPE, yyvsp[0].s); ;
     break;}
 case 55:
-#line 431 "../../fsinfo/fsi_gram.y"
+#line 414 "../../fsinfo/fsi_gram.y"
 { yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_OPTS, yyvsp[0].s); ;
     break;}
 case 56:
-#line 434 "../../fsinfo/fsi_gram.y"
+#line 417 "../../fsinfo/fsi_gram.y"
 { yyerror("unknown mount attribute"); ;
     break;}
 }
    /* the action file gets copied in in place of this dollarsign */
-#line 543 "/usr/local/gnu/share/bison.simple"
+#line 543 "/usr/local/share/bison.simple"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1330,4 +1314,4 @@ yyerrhandle:
     }
   return 1;
 }
-#line 436 "../../fsinfo/fsi_gram.y"
+#line 419 "../../fsinfo/fsi_gram.y"
